@@ -76,34 +76,18 @@ class Bibref(Parameter):
     shortbib: Optional[str] = ""
 
 
-# And a special class for the Spin and Taxonomy lists
+# And a special class for the Spin list
 class ParameterList(list):
-    """Subclass of <list> with a custom __str__ for the Spin and Taxonomy parameters."""
+    """Subclass of <list> with a custom __str__ for the Spin parameters."""
 
     def __init__(self, list_):
-        """Convert the list items to Spin or Taxonomy instances."""
-
-        if "class" in list_[0]:
-            list_ = [Taxonomy(**entry) for entry in list_]
-        else:
-            list_ = [Spin(**entry) for entry in list_]
+        """Convert the list items to Spin instances."""
+        list_ = [Spin(**entry) for entry in list_]
 
         return super().__init__(list_)
 
     def __str__(self) -> str:
 
-        if hasattr(self[0], "class_"):
-            if len(self) == 1:
-                return self[0].class_
-            else:
-                classifications = []
-
-                for entry in self:
-                    shortbib = ", ".join(bib.shortbib for bib in entry.bibref)
-                    classifications.append(f"{entry.class_:<4}{shortbib}")
-
-                return "\n".join(classifications)
-
         return super().__str__()
 
 
@@ -213,11 +197,12 @@ class Albedo(Value):
     method: List[Method] = []
 
 
-class Color(Value):
+class Color(Parameter):
     color: Value = Value(**{})
     epoch: Optional[float] = np.nan
-    from_: Optional[str] = pydantic.Field("", alias="from")
-    bibref: Bibref = Bibref(**{})
+    method: List[Method] = []
+    bibref: List[Bibref] = []
+    facility: Optional[str] = ""
     observer: Optional[str] = ""
     phot_sys: Optional[str] = ""
     delta_time: Optional[float] = np.nan
@@ -225,13 +210,32 @@ class Color(Value):
     id_filter_2: Optional[str] = ""
 
 
-class Colors(Parameter):
-    # Atlas
-    c_o: List[Color] = [pydantic.Field(Color(**{}), alias="c-o")]
-    # 2MASS / VISTA
-    J_H: List[Color] = [pydantic.Field(Color(**{}), alias="J-H")]
-    J_K: List[Color] = [pydantic.Field(Color(**{}), alias="J-K")]
-    H_K: List[Color] = [pydantic.Field(Color(**{}), alias="H-K")]
+class Color(Parameter):
+    g_i: Color = pydantic.Field(Color(**{}), alias="g-i")
+    g_r: Color = pydantic.Field(Color(**{}), alias="g-r")
+    g_z: Color = pydantic.Field(Color(**{}), alias="g-z")
+    i_z: Color = pydantic.Field(Color(**{}), alias="i-z")
+    r_i: Color = pydantic.Field(Color(**{}), alias="r-i")
+    r_z: Color = pydantic.Field(Color(**{}), alias="r-z")
+    u_g: Color = pydantic.Field(Color(**{}), alias="u-g")
+    u_g: Color = pydantic.Field(Color(**{}), alias="u-g")
+    u_r: Color = pydantic.Field(Color(**{}), alias="u-r")
+    u_z: Color = pydantic.Field(Color(**{}), alias="u-z")
+    J_K: Color = pydantic.Field(Color(**{}), alias="J-K")
+    Y_J: Color = pydantic.Field(Color(**{}), alias="Y-J")
+    Y_K: Color = pydantic.Field(Color(**{}), alias="Y-K")
+    c_o: Color = pydantic.Field(Color(**{}), alias="c-o")
+    v_g: Color = pydantic.Field(Color(**{}), alias="v-g")
+    v_i: Color = pydantic.Field(Color(**{}), alias="v-i")
+    v_r: Color = pydantic.Field(Color(**{}), alias="v-r")
+    v_z: Color = pydantic.Field(Color(**{}), alias="v-z")
+    H_K: Color = pydantic.Field(Color(**{}), alias="H-K")
+    J_H: Color = pydantic.Field(Color(**{}), alias="J-H")
+    Y_H: Color = pydantic.Field(Color(**{}), alias="Y-H")
+    u_v: Color = pydantic.Field(Color(**{}), alias="u-v")
+    V_I: Color = pydantic.Field(Color(**{}), alias="V-I")
+    V_R: Color = pydantic.Field(Color(**{}), alias="V-R")
+    B_V: Color = pydantic.Field(Color(**{}), alias="B-V")
 
 
 class Density(Value):
@@ -301,7 +305,7 @@ class Taxonomy(Parameter):
     def __str__(self):
         if not self.class_:
             return "No taxonomy on record."
-        return ", ".join(self.class_)
+        return self.class_
 
 
 class ThermalInertia(Parameter):
@@ -319,11 +323,11 @@ class AbsoluteMagnitude(Value):
 class PhysicalParameters(Parameter):
     mass: Mass = Mass(**{})
     spin: ParameterList = ParameterList([{}])
-    colors: Colors = Colors(**{})
+    color: Color = pydantic.Field(Color(**{}), alias="colors")
     albedo: Albedo = Albedo(**{})
     density: Density = Density(**{})
     diameter: Diameter = Diameter(**{})
-    taxonomy: ParameterList = ParameterList([{"class": ""}])
+    taxonomy: Taxonomy = Taxonomy(**{})
     phase_function: PhaseFunction = PhaseFunction(**{})
     thermal_inertia: ThermalInertia = ThermalInertia(**{})
     absolute_magnitude: AbsoluteMagnitude = AbsoluteMagnitude(**{})
@@ -332,7 +336,7 @@ class PhysicalParameters(Parameter):
         convert_spin_to_list
     )
     _convert_list_to_parameterlist: classmethod = pydantic.validator(
-        "spin", "taxonomy", allow_reuse=True, pre=True
+        "spin", allow_reuse=True, pre=True
     )(lambda list_: ParameterList(list_))
 
 
@@ -418,7 +422,14 @@ class Rock(pydantic.BaseModel):
     )
     yarkovskies: rocks.datacloud.Yarkovskies = rocks.datacloud.Yarkovskies(**{})
 
-    def __init__(self, id_, ssocard=None, datacloud=None, skip_id_check=False):
+    def __init__(
+        self,
+        id_,
+        ssocard=None,
+        datacloud=None,
+        skip_id_check=False,
+        suppress_errors=False,
+    ):
         """Identify a minor body  and retrieve its properties from SsODNet.
 
         Parameters
@@ -434,6 +445,8 @@ class Rock(pydantic.BaseModel):
         skip_id_check : bool
             Optional argument to prevent resolution of ID before getting ssoCard.
             Default is False.
+        suppress_errors: bool
+            Do not print errors in the ssoCard. Default is False.
 
         Returns
         -------
@@ -499,7 +512,8 @@ class Rock(pydantic.BaseModel):
             super().__init__(**ssocard)  # type: ignore
         except pydantic.ValidationError as message:
 
-            self.__parse_error_message(message, id_, ssocard)
+            if not suppress_errors:
+                self.__parse_error_message(message, id_, ssocard)
 
             # Set the offending properties to None to allow for instantiation anyway
             for error in message.errors():
@@ -638,7 +652,6 @@ class Rock(pydantic.BaseModel):
 
     def __parse_error_message(self, message, id_, data):
         """Print informative error message if ssocard data is invalid."""
-        print(f"\n{id_}:")
 
         # Look up offending value in ssoCard
         for error in message.errors():
@@ -657,24 +670,24 @@ class Rock(pydantic.BaseModel):
                     break
 
             rich.print(
-                f"Error: {' -> '.join([str(e) for e in error['loc']])} is invalid: {error['msg']}\n"
-                f"Passed value: {value}\n"
-                f"Replacing value with empty default to continue.\n"
+                f"[blue]Warning[/] [magenta]object:{id_}[/] Invalid value for {'.'.join([str(e) for e in error['loc']])}"
+                # f"\nPassed value: {value}"
             )
 
     __aliases = {
         "dynamical": {
             "parameters.dynamical.orbital_elements": "orbital_elements",
-            "parameters.dynamical.proper_elements": "proper_elements",
-            "parameters.dynamical.yarkovsky": "yarkovsky",
             "parameters.dynamical.family": "family",
             "parameters.dynamical.pair": "pair",
+            "parameters.dynamical.proper_elements": "proper_elements",
+            "parameters.dynamical.tisserand_parameter": "tisserand_parameter",
+            "parameters.dynamical.yarkovsky": "yarkovsky",
         },
         "physical": {
             "H": "absolute_magnitude",
             "parameters.physical.absolute_magnitude": "absolute_magnitude",
             "parameters.physical.albedo": "albedo",
-            "parameters.physical.colors": "colors",
+            "parameters.physical.colors": "color",
             "parameters.physical.diameter": "diameter",
             "parameters.physical.density": "density",
             "parameters.physical.mass": "mass",
@@ -698,11 +711,11 @@ class Rock(pydantic.BaseModel):
     }
 
 
-def rocks_(ids, datacloud=None, progress=False):
+def rocks_(ids, datacloud=None, progress=False, suppress_errors=False):
     """Create multiple Rock instances.
 
     Parameters
-    ==========
+    ----------
     ids : list of str, list of int, list of float, np.array, pd.Series
         An iterable containing minor body identifiers.
     datacloud : list of str
@@ -710,9 +723,11 @@ def rocks_(ids, datacloud=None, progress=False):
         Default is no additional catalogues.
     progress : bool
         Show progress of instantiation. Default is False.
+    suppress_errors: bool
+        Do not print errors in the ssoCard. Default is False.
 
     Returns
-    =======
+    -------
     list of rocks.core.Rock
         A list of Rock instances
     """
@@ -748,7 +763,14 @@ def rocks_(ids, datacloud=None, progress=False):
             )
 
     rocks_ = [
-        Rock(id_, skip_id_check=True, datacloud=datacloud) if not id_ is None else None
+        Rock(
+            id_,
+            skip_id_check=True,
+            datacloud=datacloud,
+            suppress_errors=suppress_errors,
+        )
+        if not id_ is None
+        else None
         for id_ in ids
     ]
 
